@@ -1,4 +1,4 @@
-from Button import button
+import Button
 import questions
 import pygame
 import pygame.gfxdraw
